import { EntityRepository, Repository } from "typeorm";
import { CommonCmsEntity } from "./entities/common-cms.entity";
import { UpdateCommonCmsDto } from "./dto/update-common-cms.dto";

@EntityRepository(CommonCmsEntity)
export class CommonCmsRepository extends Repository<CommonCmsEntity> {

    async createEntity(dto: UpdateCommonCmsDto): Promise<CommonCmsEntity | Error> {
        try {
            const entity = this.create({
                brandSectionTitle: dto.brandSectionTitle,
                brandSectionSubTitle: dto.brandSectionSubTitle,
                categorySectionTitle: dto.categorySectionTitle,
                popularFlowerSectionTitle: dto.popularFlowerSectionTitle,
                popularFlowerSectionSubTitle: dto.popularFlowerSectionSubTitle
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateCommonCmsDto, id: string): Promise<CommonCmsEntity | Error> {
        try {
            await this.update(id, {
                brandSectionTitle: dto.brandSectionTitle,
                brandSectionSubTitle: dto.brandSectionSubTitle,
                categorySectionTitle: dto.categorySectionTitle,
                popularFlowerSectionTitle: dto.popularFlowerSectionTitle,
                popularFlowerSectionSubTitle: dto.popularFlowerSectionSubTitle
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<CommonCmsEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}