import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateContactUsSectionOneDto } from "./dto/create-contact-us-section-one.dto";
import { ContactUsSectionOneEntity } from "./entities/contact-us-section-one.entity";
import { UpdateContactUsSectionOneDto } from "./dto/update-contact-us-section-one.dto";

@EntityRepository(ContactUsSectionOneEntity)
export class ContactUsSectionOneRepository extends Repository<ContactUsSectionOneEntity> {
    async createEntity(dto: CreateContactUsSectionOneDto): Promise<ContactUsSectionOneEntity | Error> {
        try {
            const {
                icon,
                title,
                subTitle,
                buttonText,
                buttonLink
            } = dto;
            const entity = this.create({
                icon,
                title,
                subTitle,
                buttonText,
                buttonLink
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ContactUsSectionOneEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ContactUsSectionOneEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ContactUsSectionOneEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateContactUsSectionOneDto): Promise<ContactUsSectionOneEntity | Error> {
        try {
            await this.update(id, {
                icon: dto.icon,
                title: dto.title,
                subTitle: dto.subTitle,
                buttonText: dto.buttonText,
                buttonLink: dto.buttonLink
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }
}