import { Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { fetchMOWithOrderNumber, fetchMultipleOrder, fetchOneOrder } from "src/helper/dutchie-plus-query";
import { getGraphQLClientWithApiKey } from "src/helper/graphql-client-helper";
import { RetailerServiceRepository } from "../custom/retailer-service/retailer-service.repository";

@Injectable()
export class OrderService {
    constructor(
        @InjectRepository(RetailerServiceRepository)
        private readonly retailerServiceRepo: RetailerServiceRepository
    ) {
    }

    async fetchOneOrder(variables: any) {
        try {
            const retailerService = await this.retailerServiceRepo.findOne({
                where: {
                    retailerId: variables.retailerId,
                    isDeleted: false
                }
            });
            if (retailerService) {
                const graphQLClient = getGraphQLClientWithApiKey(retailerService.apiKeyName);
                const query = fetchOneOrder();
                return await graphQLClient.request(query, variables);
            } else {
                return [];
            }
        } catch (e) {
            return e;
        }
    }

    async fetchMultipleOrderWithEmail(variables: any) {
        try {
            const retailerService = await this.retailerServiceRepo.findOne({
                where: {
                    retailerId: variables.retailerId,
                    isDeleted: false
                }
            });
            if (retailerService) {
                const graphQLClient = getGraphQLClientWithApiKey(retailerService.apiKeyName);
                const query = fetchMultipleOrder();
                const data = await graphQLClient.request(query, variables);
                return data.orders.filter(function(x: any) {
                    return x.customer.email === variables.email;
                });
            } else {
                return [];
            }
        } catch (e) {
            return e;
        }
    }

    async fetchMultipleOrderWithOrderNumber(variables: any) {
        try {
            const retailerService = await this.retailerServiceRepo.findOne({
                where: {
                    retailerId: variables.retailerId,
                    isDeleted: false
                }
            });
            if (retailerService) {
                const graphQLClient = getGraphQLClientWithApiKey(retailerService.apiKeyName);
                const query = fetchMOWithOrderNumber();
                return await graphQLClient.request(query, variables);
            } else {
                return [];
            }
        } catch (e) {
            return e;
        }
    }
}
