import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateInstagramServiceDto } from "./dto/create-instagram-service.dto";
import { UpdateInstagramServiceDto } from "./dto/update-instagram-service.dto";
import { InstagramServiceEntity } from "./entities/instagram-service.entity";

@EntityRepository(InstagramServiceEntity)
export class InstagramServiceRepository extends Repository<InstagramServiceEntity> {
    async createEntity(dto: CreateInstagramServiceDto): Promise<InstagramServiceEntity | Error> {
        try {
            const {
                media_type,
                permalink,
                media_url,
                username,
                caption,
                timestamp
            } = dto;
            const entity = this.create({
                media_type,
                permalink,
                media_url,
                username,
                caption,
                timestamp
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<InstagramServiceEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<InstagramServiceEntity | Error> {
        try {
            return await this.findOne({ where: { id: id } });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateInstagramServiceDto): Promise<InstagramServiceEntity | Error> {
        try {
            await this.update(id, {
                media_type: dto.media_type,
                permalink: dto.permalink,
                media_url: dto.media_url,
                username: dto.username,
                caption: dto.caption,
                timestamp: dto.timestamp
            });
            return await this.findOne({ where: { id: id } });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(InstagramServiceEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}